@@ -24,7 +24,7 @@ from tests import common
 class TestProjectUndo(common.TestCase):
 
     def setUp(self):
-        super(TestProjectUndo, self).setUp()
+        super().setUp()
         self.app = common.create_pitivi()
         self.project = self.app.project_manager.new_blank_project()
         self.action_log = self.app.action_log
